@@ -25,12 +25,15 @@ import logging
 import pickle
 from io import BytesIO
 from itertools import starmap
+from typing import Callable, ClassVar, Literal
 
 from translate.misc.multistring import multistring
 from translate.storage.placeables import StringElem
 from translate.storage.placeables import parse as rich_parse
 from translate.storage.workflow import StateEnum as states
 
+logger = logging.getLogger(__name__)
+
 # Simple BOM based encoding detection
 ENCODING_BOMS = (
     (codecs.BOM_UTF8, "utf-8-sig"),
@@ -76,7 +79,7 @@ class TranslationUnit:
 
     """
 
-    rich_parsers = []
+    rich_parsers: list[Callable[[str], list[StringElem]]] = []
     """A list of functions to use for parsing a string into a rich string
     tree."""
 
@@ -111,7 +114,7 @@ class TranslationUnit:
     # """
     #
     # ... but by default a format will not support state:
-    STATE = {}
+    STATE: dict[states, tuple[states, states]] = {}
 
     _store = None
     _source = None
@@ -548,13 +551,13 @@ class TranslationUnit:
 class TranslationStore:
     """Base class for stores for multiple translation units of type UnitClass."""
 
-    UnitClass = TranslationUnit
+    UnitClass: ClassVar[type[TranslationUnit]] = TranslationUnit
     """The class of units that will be instantiated and used by this class"""
     Name = "Base translation store"
     """The human usable name of this store type"""
-    Mimetypes = None
+    Mimetypes: ClassVar[list[str]] = []
     """A list of MIME types associated with this store type"""
-    Extensions = None
+    Extensions: ClassVar[list[str]] = []
     """A list of file extentions associated with this store type"""
     _binary = False
     """Indicates whether a file should be accessed as a binary file."""
@@ -824,7 +827,7 @@ class TranslationStore:
 
     def detect_encoding(
         self, text: bytes, default_encodings: list[str] | None = None
-    ) -> tuple[str, str]:
+    ) -> tuple[str | None, str | None]:
         """
         Try to detect a file encoding from `text`, using either the chardet lib
         or by trying to decode the file.
@@ -866,7 +869,7 @@ class TranslationStore:
             if encoding == self.encoding and suffix == "sig":
                 encodings.append(detected_encoding["encoding"])
             elif detected_encoding["encoding"] != self.encoding:
-                logging.warning(
+                logger.warning(
                     "trying to parse %s with encoding: %s but "
                     "detected encoding is %s (confidence: %s)",
                     self.filename,
@@ -978,8 +981,12 @@ class UnitId:
         return self.__class__([*self.parts, (key, value)])
 
     @classmethod
-    def from_string(cls, text):
-        result = []
+    def from_key(cls, text: str) -> UnitId:
+        return cls([("key", text)])
+
+    @classmethod
+    def from_string(cls, text: str) -> UnitId:
+        result: list[tuple[Literal["key", "index"], str | int]] = []
         # Strip possible leading separator
         text = text.removeprefix(cls.KEY_SEPARATOR)
         for item in text.split(cls.KEY_SEPARATOR):
@@ -1041,6 +1048,9 @@ class DictUnit(TranslationUnit):
             if not use_list and isinstance(target[key], list):
                 # Convert list to dict if needed
                 target[key] = dict(enumerate(target[key]))
+            elif use_list and isinstance(target[key], dict):
+                # Replace with an empty list if needed (this loses previous content)
+                target[key] = []
             # Handle placeholders
             if target[key] is None:
                 target[key] = default.copy()
